﻿using System;
using System.Collections.Generic;
using System.Linq;

using Xamarin.Forms;

namespace SFDataGridCrash.Views
{
    public class CerealPage : ContentPage
    {
        private string currentSearchString;
        private PlayersGrid gridView;

        public SearchBar SearchBar { get; set; }

        protected List<Cereal> Cereals { get; set; }

        protected List<Cereal> FilteredCereals { get; set; }

        public CerealPage()
        {
            this.gridView = new PlayersGrid();
            this.gridView.Grid.BackgroundColor = Color.LightBlue;

            this.gridView.GridTapped = async (cereal) =>
            {
                if (cereal != null)
                {
                    var page = new ItemDetailPage(cereal);
                    await Navigation.PushAsync(page);
                }
            };

            // Create searchbar
            this.SearchBar = new SearchBar();
            this.SearchBar.Placeholder = "Enter search terms";
            this.SearchBar.SearchButtonPressed += (sender, args) => this.PerformSearch();
            this.SearchBar.TextChanged += (sender, e) =>
            {
                // Reset when cleared
                if (string.IsNullOrWhiteSpace(e.NewTextValue))
                {
                    this.FilteredCereals = null;
                    this.PerformSearch();
                    this.Focus();
                }
                else if (e.NewTextValue.Length >= 2)
                {
                    this.PerformSearch();
                }
            };

            Content = new StackLayout
            {
                Spacing = 0,
                VerticalOptions = LayoutOptions.FillAndExpand,
                Padding = new Thickness(0, 0, 0, 50),
                Children = { this.SearchBar, this.gridView }
            };

            this.Cereals = CerealViewModel.GetModelData().ToList();

            this.PopulateGrid();
        }

        private void PerformSearch()
        {
            try
            {
                // Try searching for team or position first, else name search.
                this.currentSearchString = this.SearchBar.Text;

                if (!string.IsNullOrWhiteSpace(this.currentSearchString) && this.Cereals != null)
                {

                    this.FilteredCereals = this.Cereals.Where(p => p.id.ToString().Equals(this.currentSearchString, StringComparison.OrdinalIgnoreCase)).ToList();

                    if (this.FilteredCereals.Count == 0)
                    {
                        this.FilteredCereals = this.Cereals.Where(p => p.name.ToLowerInvariant().Contains(this.currentSearchString.ToLowerInvariant())).ToList();
                    }
                }

                this.PopulateGrid();
            }
            catch (Exception)
            {
                Console.WriteLine("Unable to execute search. Please try again.");
            }
        }

        private void PopulateGrid()
        {
            List<Cereal> cereals = this.FilteredCereals ?? this.Cereals;

            cereals = cereals.OrderBy(p => p.id).ToList();

            this.gridView.Grid.ItemsSource = cereals;
        }
    }
}

